// coding: utf-8
/*! Created by: Udo Schmal | https://www.gocher.me/ */
(function () {
  'use strict';
  let localLinks = document.querySelectorAll("[href^='#']");
  let hash = window.location.hash;
  let anchor = null;
  if (hash) {
    let id = hash.substring(1);
    anchor = document.getElementById(id);
  }

  function Tabsheets(tabsheets) {
    let current = -1;
    let sheets = tabsheets.children;
    let tabs = document.createElement("ul");
    let store =  tabsheets.dataset.store;
    if (store) {
      store = 'tabsheets-' + window.location.pathname + '-' + store;
    }
    tabs.className = "tabs";
    tabs.setAttribute('role', 'tablist');
    tabsheets.parentNode.insertBefore(tabs, tabsheets);
    let useSessionStorage = true;

    function toggle(event) {
      tabs[current].classList.remove("active");
      sheets[current].classList.remove("active");
      current = this.tabid;
      tabs[current].classList.add("active");
      sheets[current].classList.add("active");
      event.stopPropagation();
      if (store) {
        sessionStorage.setItem(store, current);
      }
    }

    for (let i=0; i<sheets.length; i++) {
      if (anchor && sheets[i].contains(anchor)) {
        if (current > -1) {
          sheets[current].classList.remove("active");
        }
        sheets[i].classList.add("active");
        current = i;
        useSessionStorage = false;
      } else if (sheets[i].classList.contains("active")) {
        if (current > -1) {
          sheets[i].classList.remove("active");
        } else {
          current = i;
        }
      };
      let txt, tabName = sheets[i].querySelector(".sheet-header");
      if (tabName) {
        txt = tabName.firstChild.cloneNode(false);
      } else {
        txt = document.createTextNode('undefined');
      }
      let tab = document.createElement("li");
      tab.appendChild(txt);
      tab.className = "tab";
      tab.setAttribute('tabindex', '0');
      tab.setAttribute('role', 'tab');
      if (i === current) {
        tab.classList.add("active");
      }
      tab.tabid = i;
      tabs.appendChild(tab);
      tab.addEventListener('click', toggle);
      let ids = sheets[i].querySelectorAll("[id]");
      for (let iId = 0; iId < ids.length; iId++) {
        for (let ilocalLinks = 0; ilocalLinks < localLinks.length; ilocalLinks++) {
          if (localLinks[ilocalLinks].href.split('#')[1] == ids[iId].id) {
            localLinks[ilocalLinks].addEventListener('click', function (event) {
              tab.click();
            });
          }
        }
      }
    }
    tabs = tabs.children;

    if (useSessionStorage && sessionStorage.getItem(store)) {
      if (current > -1) {
        tabs[current].classList.remove("active");
        sheets[current].classList.remove("active");
      }
      current = sessionStorage.getItem(store);
      tabs[current].classList.add("active");
      sheets[current].classList.add("active");
    } else if (current === -1) {
      current = 0;
      tabs[current].classList.add("active");
      sheets[current].classList.add("active");
    }
  }

  let tabsheetsList = document.querySelectorAll("ul.tabsheets"), cnt = tabsheetsList.length, i;
  if (cnt > 0) {
    for (i = 0; i < cnt; i++) {
      if (tabsheetsList[i].children && tabsheetsList[i].children.length > 0) {
        new Tabsheets(tabsheetsList[i]);
      }
    }
    // accessibility: handle tabindex enter keydown event
    document.addEventListener('keydown', function(event) {
      if (event.key === "Enter") {
        if (event.target.classList.contains('tab')) {
          event.target.click();
        }
      }
    });
  }
})();
